pub unsafe trait MEContentBlocker: NSObjectProtocol {
// Provided method
unsafe fn contentRulesJSON(&self) -> Retained<NSData>
where Self: Sized + Message { ... }
}Available on crate feature
MEContentBlocker only.Expand description
Methods in this protocol can be used by a mail app extension to block content in mail messages.
See also Apple’s documentation
Provided Methods