MEExtension

Trait MEExtension 

pub unsafe trait MEExtension: NSObjectProtocol + MainThreadOnly {
    // Provided methods
    unsafe fn handlerForComposeSession(
        &self,
        session: &MEComposeSession,
    ) -> Retained<ProtocolObject<dyn MEComposeSessionHandler>>
       where Self: Sized + Message { ... }
    unsafe fn handlerForMessageActions(
        &self,
    ) -> Retained<ProtocolObject<dyn MEMessageActionHandler>>
       where Self: Sized + Message { ... }
    unsafe fn handlerForContentBlocker(
        &self,
    ) -> Retained<ProtocolObject<dyn MEContentBlocker>>
       where Self: Sized + Message { ... }
    unsafe fn handlerForMessageSecurity(
        &self,
    ) -> Retained<ProtocolObject<dyn MEMessageSecurityHandler>>
       where Self: Sized + Message { ... }
}
Available on crate feature MEExtension only.
A protocol which must be adopted by the class set as extension’s NSExtensionPrincipalClass.

See also Apple’s documentation

Provided Methods

unsafe fn handlerForComposeSession( &self, session: &MEComposeSession, ) -> Retained<ProtocolObject<dyn MEComposeSessionHandler>>
where Self: Sized + Message,

Available on crate feature MEComposeSession only.

A factory method for returning an instance of MEComposeSessionHandler Parameter session: An instance of MEComposeSessionthat represents a mail compose window.

unsafe fn handlerForMessageActions( &self, ) -> Retained<ProtocolObject<dyn MEMessageActionHandler>>
where Self: Sized + Message,

Available on crate feature MEMessageActionHandler only.

A factory method for returning an instance of MEMessageActionHandler

unsafe fn handlerForContentBlocker( &self, ) -> Retained<ProtocolObject<dyn MEContentBlocker>>
where Self: Sized + Message,

Available on crate feature MEContentBlocker only.

A factory method for returning an instance of MEContentBlocker

unsafe fn handlerForMessageSecurity( &self, ) -> Retained<ProtocolObject<dyn MEMessageSecurityHandler>>
where Self: Sized + Message,

Available on crate features MEMessageDecoder and MEMessageEncoder and MEMessageSecurityHandler only.

A factory method for returning an instance of MEMessageSecurityHandler