pub unsafe trait MEMessageSecurityHandler:
MEMessageEncoder
+ MEMessageDecoder
+ MainThreadOnly {
// Provided methods
unsafe fn extensionViewControllerForMessageSigners(
&self,
message_signers: &NSArray<MEMessageSigner>,
) -> Option<Retained<MEExtensionViewController>>
where Self: Sized + Message { ... }
unsafe fn extensionViewControllerForMessageContext(
&self,
context: &NSData,
) -> Option<Retained<MEExtensionViewController>>
where Self: Sized + Message { ... }
unsafe fn primaryActionClickedForMessageContext_completionHandler(
&self,
context: &NSData,
completion_handler: &DynBlock<dyn Fn(*mut MEExtensionViewController)>,
)
where Self: Sized + Message { ... }
}Available on crate features
MEMessageDecoder and MEMessageEncoder and MEMessageSecurityHandler only.Expand description
Provided Methods
Sourceunsafe fn extensionViewControllerForMessageSigners(
&self,
message_signers: &NSArray<MEMessageSigner>,
) -> Option<Retained<MEExtensionViewController>>
Available on crate features MEExtensionViewController and MEMessageSigner and objc2-app-kit only.
unsafe fn extensionViewControllerForMessageSigners( &self, message_signers: &NSArray<MEMessageSigner>, ) -> Option<Retained<MEExtensionViewController>>
MEExtensionViewController and MEMessageSigner and objc2-app-kit only.Invoked by Mail to request a subclass of
MEExtensionViewController.Extensions can maintain any additional state in their subclasses and associate it with
messsageComposeSessioninstance.
Sourceunsafe fn extensionViewControllerForMessageContext(
&self,
context: &NSData,
) -> Option<Retained<MEExtensionViewController>>
Available on crate features MEExtensionViewController and objc2-app-kit only.
unsafe fn extensionViewControllerForMessageContext( &self, context: &NSData, ) -> Option<Retained<MEExtensionViewController>>
MEExtensionViewController and objc2-app-kit only.Invoked by Mail to request a subclass of
MEExtensionViewControllerwhen the user clicks a banner or on the extensions icon in the message header view.
Sourceunsafe fn primaryActionClickedForMessageContext_completionHandler(
&self,
context: &NSData,
completion_handler: &DynBlock<dyn Fn(*mut MEExtensionViewController)>,
)
Available on crate features block2 and MEExtensionViewController and objc2-app-kit only.
unsafe fn primaryActionClickedForMessageContext_completionHandler( &self, context: &NSData, completion_handler: &DynBlock<dyn Fn(*mut MEExtensionViewController)>, )
block2 and MEExtensionViewController and objc2-app-kit only.Invoked when the primary action for the message banner is clicked. The extension can provide an optional view controller to render any additional information.